==> ringcentral-widgets-0.12.4.tgz: package/modules/CallLogUI/CallLogUI.interface.ts <==
import Locale from 'ringcentral-integration/modules/Locale';
import CallLogger from 'ringcentral-integration/modules/CallLogger';
import RateLimiter from 'ringcentral-integration/modules/RateLimiter';
import RegionSettings from 'ringcentral-integration/modules/RegionSettings';
import DateTimeFormat from 'ringcentral-integration/modules/DateTimeFormat';
import { ActiveCallControl } from 'ringcentral-integration/modules/ActiveCallControlV2';
import RolesAndPermissions from 'ringcentral-integration/modules/RolesAndPermissions';
import ConnectivityMonitor from 'ringcentral-integration/modules/ConnectivityMonitor';
import { CallingSettings } from 'ringcentral-integration/modules/CallingSettingsV2';
import { ForwardingNumber } from 'ringcentral-integration/modules/ForwardingNumberV2';
import RouterInteraction from '../RouterInteraction';
import CallLogSection from '../CallLogSection';
import { CallLogPanelProps } from '../../components/CallLogPanel';

export interface State {}

export interface CallLogUIOptions {
  //
}

export interface Deps {
  locale: Locale;
  callLogger: CallLogger;
  rateLimiter: RateLimiter;
  regionSettings: RegionSettings;
  dateTimeFormat: DateTimeFormat;
  callLogSection: CallLogSection;
  routerInteraction: RouterInteraction;
  activeCallControl: ActiveCallControl;
  rolesAndPermissions: RolesAndPermissions;
  connectivityMonitor: ConnectivityMonitor;
  callingSettings: CallingSettings;
  forwardingNumber: ForwardingNumber;
  callLogUIOptions: CallLogUIOptions;
}

export interface CallLogUIInterface extends State {
  getUIProps(): CallLogUIProps;
  getUIFunctions(): CallLogUIFunctions;
}

export type CallLogUIProps = Partial<CallLogPanelProps>;

export type CallLogUIFunctions = Partial<CallLogPanelProps>;

==> ringcentral-widgets-0.13.0.tgz: package/modules/CallLogUI/CallLogUI.interface.ts <==
import { ActiveCallControl } from 'ringcentral-integration/modules/ActiveCallControlV2';
import { CallingSettings } from 'ringcentral-integration/modules/CallingSettingsV2';
import CallLogger from 'ringcentral-integration/modules/CallLogger';
import ConnectivityMonitor from 'ringcentral-integration/modules/ConnectivityMonitor';
import DateTimeFormat from 'ringcentral-integration/modules/DateTimeFormat';
import { ForwardingNumber } from 'ringcentral-integration/modules/ForwardingNumberV2';
import Locale from 'ringcentral-integration/modules/Locale';
import RateLimiter from 'ringcentral-integration/modules/RateLimiter';
import RegionSettings from 'ringcentral-integration/modules/RegionSettings';
import { ExtensionFeatures } from '../../../ringcentral-integration/modules/ExtensionFeatures';
import { CallLogPanelProps } from '../../components/CallLogPanel';
import CallLogSection from '../CallLogSection';
import { RouterInteraction } from '../RouterInteraction';

export interface State {}

export interface CallLogUIOptions {
  //
}

export interface Deps {
  locale: Locale;
  callLogger: CallLogger;
  rateLimiter: RateLimiter;
  regionSettings: RegionSettings;
  dateTimeFormat: DateTimeFormat;
  callLogSection: CallLogSection;
  routerInteraction: RouterInteraction;
  activeCallControl: ActiveCallControl;
  extensionFeatures: ExtensionFeatures;
  connectivityMonitor: ConnectivityMonitor;
  callingSettings: CallingSettings;
  forwardingNumber: ForwardingNumber;
  callLogUIOptions: CallLogUIOptions;
}

export interface CallLogUIInterface extends State {
  getUIProps(): CallLogUIProps;
  getUIFunctions(): CallLogUIFunctions;
}

export type CallLogUIProps = Partial<CallLogPanelProps>;

export type CallLogUIFunctions = Partial<CallLogPanelProps>;
